From 4144bc52545d38a946ec6c06f85a148f4d7406a8 Mon Sep 17 00:00:00 2001
From: tpoitzsch <>
Date: Tue, 30 Jun 2015 05:56:27 +0000
Subject: [PATCH] FRITZBOX: standard dial port 50
git-svn-id: https://svn.fhem.de/fhem/trunk@8861 2b470e98-0d58-463d-a4d8-8e2adae1ed80
---
fhem/FHEM/72_FRITZBOX.pm | 35 ++++++++++++++++++++---------------
1 file changed, 20 insertions(+), 15 deletions(-)
diff --git a/fhem/FHEM/72_FRITZBOX.pm b/fhem/FHEM/72_FRITZBOX.pm
index dc759d8ec..5bf59b2f2 100644
--- a/fhem/FHEM/72_FRITZBOX.pm
+++ b/fhem/FHEM/72_FRITZBOX.pm
@@ -511,7 +511,7 @@ sub FRITZBOX_Get($@)
#get Fritzbox tr064command LANEthernetInterfaceConfig:1 lanethernetifcfg GetStatistics
Log3 $name, 3, "FRITZBOX: get $name $cmd ".join(" ", @val);
- return "Wrong number of arguments, usage: get $name tr064command service control action [parameterName1 parameterValue1] [parameterName2 parameterValue2] ..."
+ return "Wrong number of arguments, usage: get $name tr064command service control action [argName1 argValue1] [argName2 argValue2] ..."
if int @val <3 || int(@val) %2 !=1;
$returnStr = "Result of TR064 call\n";
@@ -2569,12 +2569,12 @@ sub FRITZBOX_Ring_Run_Web($)
push @webCmdArray, "telcfg:settings/DialPort" => $ringWithIntern;
FRITZBOX_Log $hash, 4, "Set dial port to '" . $dialPort{$ringWithIntern} . "' (MSN: ".$startValue->{fonPort}->[$ringWithIntern-1]{MSN} .").";
}
- elsif ($field{show}) {
- FRITZBOX_Log $hash, 3, "Parameter 'show:' ignored because attribute 'ringWithIntern' not defined and standard dial port '".$hash->{READINGS}{box_stdDialPort}{VAL}."' is used."
- }
- # use standard dial port
+# set dial port to 50 (all Fons)
else {
- FRITZBOX_Log $hash, 5, "Use standard dial port '" . $hash->{READINGS}{box_stdDialPort}{VAL} ."'.";
+ FRITZBOX_Log $hash, 3, "Parameter 'show:' ignored because attribute 'ringWithIntern' not defined."
+ if $field{show};
+ push @webCmdArray, "telcfg:settings/DialPort" => 50;
+ FRITZBOX_Log $hash, 4, "Set dial port to 50 (all fons)";
}
# Set tts-Message
@@ -2606,7 +2606,7 @@ sub FRITZBOX_Ring_Run_Web($)
push( @webCmdArray, "telcfg:command/Hangup" => "" ) unless $hash->{SECPORT};
#Preparing 5th command array to reset everything
- push @webCmdArray, "telcfg:settings/DialPort" => $startValue->{dialPort} if $ringWithIntern != 0 && defined $startValue->{dialPort};
+ push @webCmdArray, "telcfg:settings/DialPort" => $startValue->{dialPort} if defined $startValue->{dialPort};
FRITZBOX_Log $hash, 4, "Reset dial port to '".$dialPort{$startValue->{dialPort}}."'.";
# Reset internal ring tones for the Fritz!Fons
if ($ringTone) {
@@ -4231,7 +4231,7 @@ sub FRITZBOX_fritztris($)
Only available if the attribute "allowShellCommand" is set.
-
get <name> tr064Command <service> <control> <action> [[parameterName1 parameterValue1] ...]
+ get <name> tr064Command <service> <control> <action> [[argName1 argValue1] ...]
allowTR064Command <0 | 1>
+ defaultCallerName <Text>
get <name> tr064Command <service> <control> <action> [[parameterName1 parameterValue1] ...]
+ get <name> tr064Command <service> <control> <action> [[argName1 argValue1] ...]
allowShellCommand <0 | 1>
+ allowTR064Command <0 | 1>
forceTelnetConnection <0 | 1>